typed_descriptors.base
======================

.. automodule:: typed_descriptors.base

DescriptorBase
--------------

.. autoclass:: typed_descriptors.base.DescriptorBase
    :show-inheritance:
    :members:
    :special-members: __init__, __get__

T
-

.. autodata:: typed_descriptors.base.T
